pub struct BlockchainDb<B = BlockEnv> { /* private fields */ }Expand description
A shareable Block database
Implementations
Sourceimpl<B: ForkBlockEnv> BlockchainDb<B>
impl<B: ForkBlockEnv> BlockchainDb<B>
Sourcepub fn new(meta: BlockchainDbMeta<B>, cache_path: Option<PathBuf>) -> Self
pub fn new(meta: BlockchainDbMeta<B>, cache_path: Option<PathBuf>) -> Self
Creates a new instance of the BlockchainDb.
If a cache_path is provided it attempts to load a previously stored JsonBlockCacheData
and will try to use the cached entries it holds.
This will return a new and empty MemDb if
cache_pathisNone- the file the
cache_pathpoints to, does not exist - the file contains malformed data, or if it couldn’t be read
- the provided
metadiffers from BlockchainDbMeta that’s stored on disk
Sourcepub fn new_skip_check(
meta: BlockchainDbMeta<B>,
cache_path: Option<PathBuf>,
) -> Self
pub fn new_skip_check( meta: BlockchainDbMeta<B>, cache_path: Option<PathBuf>, ) -> Self
Creates a new instance of the BlockchainDb and skips check when comparing meta
This is useful for offline-start mode when we don’t want to fetch metadata of block.
if a cache_path is provided it attempts to load a previously stored JsonBlockCacheData
and will try to use the cached entries it holds.
This will return a new and empty MemDb if
cache_pathisNone- the file the
cache_pathpoints to, does not exist - the file contains malformed data, or if it couldn’t be read
- the provided
metadiffers from BlockchainDbMeta that’s stored on disk
Sourcepub fn accounts(&self) -> &RwLock<AddressHashMap<AccountInfo>>
pub fn accounts(&self) -> &RwLock<AddressHashMap<AccountInfo>>
Returns the map that holds the account related info
Sourcepub fn storage(&self) -> &RwLock<AddressHashMap<StorageInfo>>
pub fn storage(&self) -> &RwLock<AddressHashMap<StorageInfo>>
Returns the map that holds the storage related info
Sourcepub fn block_hashes(&self) -> &RwLock<U256Map<B256>>
pub fn block_hashes(&self) -> &RwLock<U256Map<B256>>
Returns the map that holds all the block hashes
Sourcepub const fn meta(&self) -> &Arc<RwLock<BlockchainDbMeta<B>>>
pub const fn meta(&self) -> &Arc<RwLock<BlockchainDbMeta<B>>>
Returns the Env related metadata
Sourcepub const fn cache(&self) -> &Arc<JsonBlockCacheDB<B>>
pub const fn cache(&self) -> &Arc<JsonBlockCacheDB<B>>
Returns the inner cache